// Convert the model.
//
// Copyright (C) David Elworthy 2004
// All rights reserved.
//
// Redistribution and use in source and binary forms for any purpose, with or
// without modification, are permitted provided that the following conditions
// are met:
// 
// 1. Redistributions of source code must retain the above copyright notice,
//    this list of conditions, and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions, and the disclaimer that follows 
//    these conditions in the documentation and/or other materials 
//    provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
// NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
// TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// You may contact me at david@friendlymoose.com.

// This just reads a binary format model and outputs the tag and transitions
// data, in the form:
// <tag1> <tag2> <score>
// The command line names the input and output file names.
// The input file is binary, the output file is textual.

#include "tagset.h"
#include <iostream>
#include <fstream>
using namespace std;

int main(int argc, char *argv[])
{
    if (argc != 3)
    {
        cerr << "Usage: " << argv[0] << " in-file out-file" << endl;
        return -1;
    }

    ifstream infile(argv[1], ios::in | ios::binary);

    if (!infile.good())
    {
        cerr << "Unable to open model " << argv[1] << endl;
        return -1;
    }

    ofstream outfile(argv[2]);
    if (!outfile.good())
    {
        cerr << "Unable to open output " << argv[2] << endl;
        infile.close();
        return -1;
    }

    // Read just the tagset from the model
    TagSet tagset;
    if (!tagset.readBinary(infile))
    {
        cerr << "Errors reading " << argv[1] << endl;
    }
    else
    {
        // Write the tagset back out
        outfile.precision(6);
        tagset.writeTrans(outfile);
    }

    infile.close();
    outfile.close();
    return 0;
}
